# Systran Translation Client

[![pipeline status](https://gitlab.com/canarduck/systranio/badges/master/pipeline.svg)](https://gitlab.com/canarduck/systranio/commits/master) [![coverage report](https://gitlab.com/canarduck/systranio/badges/master/coverage.svg)](https://gitlab.com/canarduck/systranio/commits/master)

An unofficial python client to Systran.io APIs, [official libraries](https://github.com/SYSTRAN/translation-api-python-client) are also available.
I am *not* affiliated with Systran *at all*.

* Documentation : https://canarduck.gitlab.io/systranio
* Repository : https://gitlab.com/canarduck/systranio
* Pypi : https://pypi.python.org/pypi/systranio
